@@ -68,6 +68,7 @@ describe 'trove::taskmanager' do
         is_expected.to contain_trove_taskmanager_config('DEFAULT/heat_service_type').with_value('orchestration')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/neutron_service_type').with_value('network')
         is_expected.to contain_trove_config('DEFAULT/taskmanager_queue').with_value('taskmanager')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/taskmanager_manager').with_value('trove.taskmanager.manager.Manager')
         is_expected.to contain_file('/etc/trove/trove-guestagent.conf')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
@@ -302,36 +303,26 @@ describe 'trove::taskmanager' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily       => 'Debian',
-        :processorcount => 8
-      })
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :taskmanager_package_name => 'trove-taskmanager',
+            :taskmanager_service_name => 'trove-taskmanager' }
+        when 'RedHat'
+          { :taskmanager_package_name => 'openstack-trove-taskmanager',
+            :taskmanager_service_name => 'openstack-trove-taskmanager' }
+        end
+      end
+      it_configures 'trove-taskmanager'
     end
-
-    let :platform_params do
-      { :taskmanager_package_name => 'trove-taskmanager',
-        :taskmanager_service_name => 'trove-taskmanager' }
-    end
-
-    it_configures 'trove-taskmanager'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily       => 'RedHat',
-        :processorcount => 8
-      })
-    end
-
-    let :platform_params do
-      { :taskmanager_package_name => 'openstack-trove-taskmanager',
-        :taskmanager_service_name => 'openstack-trove-taskmanager' }
-    end
-
-    it_configures 'trove-taskmanager'
   end
 
 end
